protocol

package
v0.0.0-...-4b2ba41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 29, 2025 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package protocol contains hte public type that have to do with VPN protocols

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Protocol

type Protocol int8

Protocol defines an 'enumeration' of protocols

const (
	// Unknown indicates that the protocol is not known
	Unknown Protocol = iota
	// OpenVPN indicates that the protocol is OpenVPN
	OpenVPN
	// WireGuard indicates that the protocol is WireGuard
	WireGuard
	// WireGuardProxy indicates that the protocol is WireGuard with proxyguard
	WireGuardProxy
)

func New

func New(p string) Protocol

New creates a new protocol type from a string

Jump to